pub enum RuntimeMode {
Ambient,
Dedicated(RuntimeConfiguration),
}Expand description
Controls which runtime a supervisor runs on.
Variants
Ambient
Run on the ambient runtime (default).
The supervisor runs on whatever Tokio runtime is currently active when it is spawned.
Dedicated(RuntimeConfiguration)
Run on a dedicated runtime with the given configuration.
The supervisor spawns its own OS thread(s) and Tokio runtime, providing runtime isolation from the parent supervisor.