pub struct ProcessShutdown { /* private fields */ }Expand description
A shutdown signal for a process.
This struct can be used to wait for a shutdown signal from the supervisor to which the process belongs.
Implementations
Sourceimpl ProcessShutdown
impl ProcessShutdown
Sourcepub fn paired() -> (Self, ShutdownHandle)
pub fn paired() -> (Self, ShutdownHandle)
Creates a new ProcessShutdown and ShutdownHandle pair.
When ShutdownHandle is triggered, or dropped, ProcessShutdown will resolve.
Sourcepub fn wrapped<F: Future + Send + 'static>(future: F) -> Self
pub fn wrapped<F: Future + Send + 'static>(future: F) -> Self
Creates a new ProcessShutdown from the given future.
ProcessShutdown will be resolve only once future resolves.
Sourcepub fn noop() -> Self
pub fn noop() -> Self
Creates a new ProcessShutdown that never resolves.
This is useful for cases where a ProcessShutdown is required, but no shutdown signal is expected.
Sourcepub async fn wait_for_shutdown(&mut self)
pub async fn wait_for_shutdown(&mut self)
Waits for the shutdown signal to be received.
If the shutdown signal has been received during a previous call to this function, this function will return immediately for all subsequent calls.
ProcessShutdown also implements Future directly, which can be useful when passing it to APIs
that accept a generic future (e.g., as a shutdown signal parameter).