pub struct UnixMillis(pub u64);Expand description
A point in time, as milliseconds since the Unix epoch.
Serialized as a plain integer. The standard library’s own representation of a timestamp serializes as a pair of fields, which is awkward for a consumer that just wants to render a time.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for UnixMillis
impl Clone for UnixMillis
Sourcefn clone(&self) -> UnixMillis
fn clone(&self) -> UnixMillis
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnixMillis
impl Debug for UnixMillis
Sourceimpl Default for UnixMillis
impl Default for UnixMillis
Sourcefn default() -> UnixMillis
fn default() -> UnixMillis
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UnixMillis
impl<'de> Deserialize<'de> for UnixMillis
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for UnixMillis
impl Ord for UnixMillis
Sourcefn cmp(&self, other: &UnixMillis) -> Ordering
fn cmp(&self, other: &UnixMillis) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UnixMillis
impl PartialEq for UnixMillis
Sourceimpl PartialOrd for UnixMillis
impl PartialOrd for UnixMillis
Sourceimpl Serialize for UnixMillis
impl Serialize for UnixMillis
impl Copy for UnixMillis
impl Eq for UnixMillis
impl StructuralPartialEq for UnixMillis