pub struct ChildSpecification<S = WorkerSpec> { /* private fields */ }Expand description
A specification for a process to be added to a Supervisor.
A child specification describes how the supervisor should create and manage a child: the underlying future that
represents the process, along with metadata such as its name and shutdown strategy. All processes in a supervisor,
whether a worker or a (nested) supervisor, are represented by a ChildSpecification.
Generally, callers should prefer to use add_worker directly, which can accept either
Supervisor or any value that implements Supervisable, without needing to explicitly create a
ChildSpecification. This is preferred as it is more concise but also will ensure that relevant settings are
configured properly for the given worker type, such as using the proper shutdown strategy for supervisors to allow
for complete, graceful shutdown.
If more control is needed, ChildSpecification::worker can be used to create a specification directly, allowing
access to configuring those more advanced settings. This is currently only valid for worker processes, as
supervisors have no additional user-configurable settings.
Implementations
Sourceimpl ChildSpecification<WorkerSpec>
impl ChildSpecification<WorkerSpec>
Sourcepub fn worker<T: Supervisable + 'static>(worker: T) -> Self
pub fn worker<T: Supervisable + 'static>(worker: T) -> Self
Creates a specification for the given worker.
Sourcepub fn with_restart_type(self, restart_type: RestartType) -> Self
pub fn with_restart_type(self, restart_type: RestartType) -> Self
Sets the restart policy for this worker.
Defaults to RestartType::Permanent.